@@ -1,30 +1,26 @@
 #!/usr/bin/python
-# template2man.py template
-
-# Reads a template and outputs ma format (a bit ugly, but 
-# assures that documentation is up-to-date).
+# read templateparser output and transform to man format
 import sys
 
 ####
 def get(line):
 	return line.split(":", 1)[1].strip()
-
+	
 parameter = help = ptype = default = ""
 while 1:
 	line = sys.stdin.readline()
 	if not line: break
-	
 	if line.find("section:") == 0:
 		section = line.split()[1]
 		print ".TP"
 		print "\\fB* Section [%s]\\fR" %section
-	elif line.find("* parameter:") >= 0:
+	elif line.find("parameter:") >= 0:
 		parameter = get(line)
-	elif line.find("- default:") >= 0:
+	elif line.find("default:") >= 0:
 		default = get(line)
-	elif line.find("- type:") >= 0:
+	elif line.find("type:") >= 0:
 		ptype = get(line)
-	elif line.find("- help:") >= 0:
+	elif line.find("help:") >= 0:
 		help = get(line)
 		print ".TP"
 		print "%s: \\fI%s\\fR" %(parameter, ptype)
@@ -34,4 +30,4 @@ while 1:
 		parameter = help = ptype = default = ""
 	
 print ".PP"
-sys.exit(0)
+sys.exit(0)
\ No newline at end of file
